package java.text;

import java.io.Serializable;
import java.text.resources.LocaleData;
import java.util.Locale;

public abstract class BreakIterator implements Cloneable, Serializable {
   public static final int DONE = -1;

   protected BreakIterator() {
   }

   public Object clone() {
      try {
         return super.clone();
      } catch (CloneNotSupportedException var1) {
         throw new InternalError();
      }
   }

   public abstract int first();

   public abstract int last();

   public abstract int next(int var1);

   public abstract int next();

   public abstract int previous();

   public abstract int following(int var1);

   public abstract int current();

   public abstract CharacterIterator getText();

   public void setText(String var1) {
      this.setText((CharacterIterator)(new StringCharacterIterator(var1)));
   }

   public abstract void setText(CharacterIterator var1);

   public static BreakIterator getWordInstance() {
      return getWordInstance(Locale.getDefault());
   }

   public static BreakIterator getWordInstance(Locale var0) {
      return new SimpleTextBoundary(new WordBreakData());
   }

   public static BreakIterator getLineInstance() {
      return getLineInstance(Locale.getDefault());
   }

   public static BreakIterator getLineInstance(Locale var0) {
      return new SimpleTextBoundary(new LineBreakData());
   }

   public static BreakIterator getCharacterInstance() {
      return getCharacterInstance(Locale.getDefault());
   }

   public static BreakIterator getCharacterInstance(Locale var0) {
      return new SimpleTextBoundary(new CharacterBreakData());
   }

   public static BreakIterator getSentenceInstance() {
      return getSentenceInstance(Locale.getDefault());
   }

   public static BreakIterator getSentenceInstance(Locale var0) {
      return new SimpleTextBoundary(new SentenceBreakData());
   }

   public static synchronized Locale[] getAvailableLocales() {
      return LocaleData.getAvailableLocales("NumberPatterns");
   }
}
