package java.text;

import java.text.resources.LocaleData;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import java.util.TimeZone;

public abstract class DateFormat extends Format implements Cloneable {
   protected Calendar calendar;
   protected NumberFormat numberFormat;
   public static final int ERA_FIELD = 0;
   public static final int YEAR_FIELD = 1;
   public static final int MONTH_FIELD = 2;
   public static final int DATE_FIELD = 3;
   public static final int HOUR_OF_DAY1_FIELD = 4;
   public static final int HOUR_OF_DAY0_FIELD = 5;
   public static final int MINUTE_FIELD = 6;
   public static final int SECOND_FIELD = 7;
   public static final int MILLISECOND_FIELD = 8;
   public static final int DAY_OF_WEEK_FIELD = 9;
   public static final int DAY_OF_YEAR_FIELD = 10;
   public static final int DAY_OF_WEEK_IN_MONTH_FIELD = 11;
   public static final int WEEK_OF_YEAR_FIELD = 12;
   public static final int WEEK_OF_MONTH_FIELD = 13;
   public static final int AM_PM_FIELD = 14;
   public static final int HOUR1_FIELD = 15;
   public static final int HOUR0_FIELD = 16;
   public static final int TIMEZONE_FIELD = 17;
   public static final int FULL = 0;
   public static final int LONG = 1;
   public static final int MEDIUM = 2;
   public static final int SHORT = 3;
   public static final int DEFAULT = 2;

   public final StringBuffer format(Object var1, StringBuffer var2, FieldPosition var3) {
      if (var1 instanceof Number) {
         return this.format(new Date(((Number)var1).longValue()), var2, var3);
      } else if (var1 instanceof Date) {
         return this.format((Date)var1, var2, var3);
      } else {
         throw new IllegalArgumentException("Cannot format given Object as a Date");
      }
   }

   public abstract StringBuffer format(Date var1, StringBuffer var2, FieldPosition var3);

   public final String format(Date var1) {
      return this.format(var1, new StringBuffer(), new FieldPosition(0)).toString();
   }

   public Date parse(String var1) throws ParseException {
      ParsePosition var2 = new ParsePosition(0);
      Date var3 = this.parse(var1, var2);
      if (var2.index == 0) {
         throw new ParseException("Unparseable date: \"" + var1 + "\"", 0);
      } else {
         return var3;
      }
   }

   public abstract Date parse(String var1, ParsePosition var2);

   public Object parseObject(String var1, ParsePosition var2) {
      return this.parse(var1, var2);
   }

   public static final DateFormat getTimeInstance() {
      return get(2, -1, Locale.getDefault());
   }

   public static final DateFormat getTimeInstance(int var0) {
      return get(var0, -1, Locale.getDefault());
   }

   public static final DateFormat getTimeInstance(int var0, Locale var1) {
      return get(var0, -1, var1);
   }

   public static final DateFormat getDateInstance() {
      return get(-1, 6, Locale.getDefault());
   }

   public static final DateFormat getDateInstance(int var0) {
      return get(-1, var0 + 4, Locale.getDefault());
   }

   public static final DateFormat getDateInstance(int var0, Locale var1) {
      return get(-1, var0 + 4, var1);
   }

   public static final DateFormat getDateTimeInstance() {
      return get(2, 6, Locale.getDefault());
   }

   public static final DateFormat getDateTimeInstance(int var0, int var1) {
      return get(var1, var0 + 4, Locale.getDefault());
   }

   public static final DateFormat getDateTimeInstance(int var0, int var1, Locale var2) {
      return get(var1, var0 + 4, var2);
   }

   public static final DateFormat getInstance() {
      return getDateTimeInstance(3, 3);
   }

   public static Locale[] getAvailableLocales() {
      return LocaleData.getAvailableLocales("DateTimePatterns");
   }

   public void setCalendar(Calendar var1) {
      this.calendar = var1;
   }

   public Calendar getCalendar() {
      return this.calendar;
   }

   public void setNumberFormat(NumberFormat var1) {
      this.numberFormat = var1;
   }

   public NumberFormat getNumberFormat() {
      return this.numberFormat;
   }

   public void setTimeZone(TimeZone var1) {
      this.calendar.setTimeZone(var1);
   }

   public TimeZone getTimeZone() {
      return this.calendar.getTimeZone();
   }

   public void setLenient(boolean var1) {
      this.calendar.setLenient(var1);
   }

   public boolean isLenient() {
      return this.calendar.isLenient();
   }

   public int hashCode() {
      return this.numberFormat.hashCode();
   }

   public boolean equals(Object var1) {
      if (this == var1) {
         return true;
      } else if (this.getClass() != var1.getClass()) {
         return false;
      } else {
         DateFormat var2 = (DateFormat)var1;
         return this.calendar.equals(var2.calendar) && this.numberFormat.equals(var2.numberFormat);
      }
   }

   public Object clone() {
      DateFormat var1 = (DateFormat)super.clone();
      var1.calendar = (Calendar)this.calendar.clone();
      var1.numberFormat = (NumberFormat)this.numberFormat.clone();
      return var1;
   }

   private static DateFormat get(int var0, int var1, Locale var2) {
      try {
         ResourceBundle.getBundle("java.text.resources.LocaleElements", var2);
         return new SimpleDateFormat(var0, var1, var2);
      } catch (MissingResourceException var3) {
         return new SimpleDateFormat("M/d/yy h:mm a");
      }
   }

   protected DateFormat() {
   }
}
