package java.text;

final class WordBreakData extends TextBoundaryData {
   private static final byte BREAK = 0;
   private static final byte letter = 1;
   private static final byte number = 2;
   private static final byte midLetter = 3;
   private static final byte midLetNum = 4;
   private static final byte preNum = 5;
   private static final byte postNum = 6;
   private static final byte midNum = 7;
   private static final byte preMidNum = 8;
   private static final byte blank = 9;
   // $FF: renamed from: cr byte
   private static final byte field_0 = 10;
   private static final byte kata = 11;
   private static final byte hira = 12;
   private static final byte kanji = 13;
   private static final byte diacrit = 14;
   private static final int COL_COUNT = 15;
   // $FF: renamed from: SI byte
   private static final byte field_1 = -128;
   private static final byte[] kWordForwardData = new byte[]{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -124, -126, -125, -124, -124, -123, -124, -124, -123, -122, -124, -118, -117, -116, -119, -128, -126, -125, -121, -121, -128, -128, -128, -121, -128, -128, -128, -128, -128, -128, -128, -126, -125, -128, -120, -128, -124, -120, -120, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -125, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -122, -124, -128, -128, -128, -128, 0, -126, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -125, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -118, -117, -128, -119, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -118, -128, -128, -118, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -117, -128, -117, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -128, -116, -128};
   private static final WordBreakTable kWordForward;
   private static final byte[] kWordBackwardData;
   private static final WordBreakTable kWordBackward;
   private static final int[] kRawMapping;
   private static SpecialMapping[] kExceptionChar;
   private static final UnicodeClassMapping kWordMap;

   public WordBreakTable forward() {
      return kWordForward;
   }

   public WordBreakTable backward() {
      return kWordBackward;
   }

   public UnicodeClassMapping map() {
      return kWordMap;
   }

   static {
      kWordForward = new WordBreakTable(15, kWordForwardData);
      kWordBackwardData = new byte[]{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -122, -126, -125, -124, -123, -122, -121, -121, -123, -120, -120, -119, -118, -116, -117, 0, -126, -125, 4, 4, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, -126, -125, 0, 7, -128, 0, 7, -121, 0, 0, 0, 0, 0, 0, 0, -126, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -126, -125, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -125, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -120, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -119, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -118, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -119, -118, 0, -117, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -116, 0};
      kWordBackward = new WordBreakTable(15, kWordBackwardData);
      kRawMapping = new int[]{0, 1, 1, 1, 1, 1, 0, 0, 0, 2, 1, 2, 9, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 5, 0, 0};
      kExceptionChar = new SpecialMapping[]{new SpecialMapping('\t', 9), new SpecialMapping('\n', 10), new SpecialMapping('\f', '\r', 10), new SpecialMapping('"', 4), new SpecialMapping('#', 5), new SpecialMapping('%', 6), new SpecialMapping('&', 6), new SpecialMapping('\'', 4), new SpecialMapping(',', 7), new SpecialMapping('.', 8), new SpecialMapping('¢', 6), new SpecialMapping('\u00ad', 3), new SpecialMapping('٪', 6), new SpecialMapping('٫', 7), new SpecialMapping('‧', 3), new SpecialMapping('\u2028', '\u2029', 10), new SpecialMapping('‰', 6), new SpecialMapping('‱', 6), new SpecialMapping('ぁ', 'ゔ', 12), new SpecialMapping('゙', '゜', 14), new SpecialMapping('ァ', 'ヶ', 11), new SpecialMapping('一', '龥', 13), new SpecialMapping('가', '힣', 1), new SpecialMapping('豈', '鶴', 13)};
      kWordMap = new UnicodeClassMapping(kRawMapping, kExceptionChar);
   }
}
